AsyncResult<T> class

Constructors

AsyncResult.failure(Object error, [StackTrace? stackTrace])
factory
AsyncResult.success(T value)
factory

Properties

error Object
no setter
hashCode int
The hash code for this object.
no setterinherited
isFailure bool
no setter
isSuccess bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T
no setter

Methods

getOrElse(T fallback) → T
getOrNull() → T?
map<R>(R transform(T)) AsyncResult<R>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override
when<R>({required R success(T value), required R failure(Object error)}) → R

Operators

operator ==(Object other) bool
The equality operator.
inherited